#[repr(C)]pub struct AVPictureInPictureController { /* private fields */ }Available on crate feature
AVPictureInPictureController only.Implementations
sourceimpl AVPictureInPictureController
impl AVPictureInPictureController
pub unsafe fn isPictureInPictureSupported() -> bool
pub unsafe fn pictureInPictureButtonStartImage() -> Retained<NSImage>
Available on crate feature
objc2-app-kit and macOS only.pub unsafe fn pictureInPictureButtonStopImage() -> Retained<NSImage>
Available on crate feature
objc2-app-kit and macOS only.pub unsafe fn initWithContentSource( this: Allocated<Self>, content_source: &AVPictureInPictureControllerContentSource ) -> Retained<Self>
pub unsafe fn contentSource( &self ) -> Option<Retained<AVPictureInPictureControllerContentSource>>
pub unsafe fn setContentSource( &self, content_source: Option<&AVPictureInPictureControllerContentSource> )
pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn AVPictureInPictureControllerDelegate>>>
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn AVPictureInPictureControllerDelegate>> )
pub unsafe fn startPictureInPicture(&self)
pub unsafe fn stopPictureInPicture(&self)
pub unsafe fn isPictureInPicturePossible(&self) -> bool
pub unsafe fn isPictureInPictureActive(&self) -> bool
pub unsafe fn isPictureInPictureSuspended(&self) -> bool
pub unsafe fn canStopPictureInPicture(&self) -> bool
pub unsafe fn requiresLinearPlayback(&self) -> bool
pub unsafe fn setRequiresLinearPlayback(&self, requires_linear_playback: bool)
pub unsafe fn canStartPictureInPictureAutomaticallyFromInline(&self) -> bool
pub unsafe fn setCanStartPictureInPictureAutomaticallyFromInline( &self, can_start_picture_in_picture_automatically_from_inline: bool )
sourceimpl AVPictureInPictureController
impl AVPictureInPictureController
Methods declared on superclass NSObject
sourceimpl AVPictureInPictureController
impl AVPictureInPictureController
pub unsafe fn invalidatePlaybackState(&self)
Available on crate feature
AVPictureInPictureController_AVSampleBufferDisplayLayerSupport only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.