AVPictureInPictureControllerDelegate

Trait AVPictureInPictureControllerDelegate 

pub unsafe trait AVPictureInPictureControllerDelegate: NSObjectProtocol {
    // Provided methods
    unsafe fn pictureInPictureControllerWillStartPictureInPicture(
        &self,
        picture_in_picture_controller: &AVPictureInPictureController,
    )
       where Self: Sized + Message { ... }
    unsafe fn pictureInPictureControllerDidStartPictureInPicture(
        &self,
        picture_in_picture_controller: &AVPictureInPictureController,
    )
       where Self: Sized + Message { ... }
    unsafe fn pictureInPictureController_failedToStartPictureInPictureWithError(
        &self,
        picture_in_picture_controller: &AVPictureInPictureController,
        error: &NSError,
    )
       where Self: Sized + Message { ... }
    unsafe fn pictureInPictureControllerWillStopPictureInPicture(
        &self,
        picture_in_picture_controller: &AVPictureInPictureController,
    )
       where Self: Sized + Message { ... }
    unsafe fn pictureInPictureControllerDidStopPictureInPicture(
        &self,
        picture_in_picture_controller: &AVPictureInPictureController,
    )
       where Self: Sized + Message { ... }
    unsafe fn pictureInPictureController_restoreUserInterfaceForPictureInPictureStopWithCompletionHandler(
        &self,
        picture_in_picture_controller: &AVPictureInPictureController,
        completion_handler: &DynBlock<dyn Fn(Bool)>,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature AVPictureInPictureController only.
A protocol for delegates of AVPictureInPictureController.

See also Apple’s documentation

Provided Methods

unsafe fn pictureInPictureControllerWillStartPictureInPicture( &self, picture_in_picture_controller: &AVPictureInPictureController, )
where Self: Sized + Message,

Parameter pictureInPictureController: The Picture in Picture controller.

Delegate can implement this method to be notified when Picture in Picture will start.

unsafe fn pictureInPictureControllerDidStartPictureInPicture( &self, picture_in_picture_controller: &AVPictureInPictureController, )
where Self: Sized + Message,

Parameter pictureInPictureController: The Picture in Picture controller.

Delegate can implement this method to be notified when Picture in Picture did start.

unsafe fn pictureInPictureController_failedToStartPictureInPictureWithError( &self, picture_in_picture_controller: &AVPictureInPictureController, error: &NSError, )
where Self: Sized + Message,

Parameter pictureInPictureController: The Picture in Picture controller.

Parameter error: An error describing why it failed.

Delegate can implement this method to be notified when Picture in Picture failed to start.

unsafe fn pictureInPictureControllerWillStopPictureInPicture( &self, picture_in_picture_controller: &AVPictureInPictureController, )
where Self: Sized + Message,

Parameter pictureInPictureController: The Picture in Picture controller.

Delegate can implement this method to be notified when Picture in Picture will stop.

unsafe fn pictureInPictureControllerDidStopPictureInPicture( &self, picture_in_picture_controller: &AVPictureInPictureController, )
where Self: Sized + Message,

Parameter pictureInPictureController: The Picture in Picture controller.

Delegate can implement this method to be notified when Picture in Picture did stop.

unsafe fn pictureInPictureController_restoreUserInterfaceForPictureInPictureStopWithCompletionHandler( &self, picture_in_picture_controller: &AVPictureInPictureController, completion_handler: &DynBlock<dyn Fn(Bool)>, )
where Self: Sized + Message,

Available on crate feature block2 only.

Parameter pictureInPictureController: The Picture in Picture controller.

Parameter completionHandler: The completion handler the delegate needs to call after restore.

Delegate can implement this method to restore the user interface before Picture in Picture stops.