Struct AVPlayerView

#[repr(C)]
pub struct AVPlayerView { /* private fields */ }
Available on crate feature AVPlayerView and crate feature objc2-app-kit and macOS only.
AVPlayerView is a subclass of NSView that can be used to display the visual content of an AVPlayer object and the standard playback controls.

See also Apple’s documentation

Implementations

Source

impl AVPlayerView

pub unsafe fn player(&self) -> Option<Retained<AVPlayer>>

Available on crate feature objc2-av-foundation only.

The player from which to source the media content for the view.

pub unsafe fn setPlayer(&self, player: Option<&AVPlayer>)

Available on crate feature objc2-av-foundation only.

Setter for player.

pub unsafe fn controlsStyle(&self) -> AVPlayerViewControlsStyle

The style of the playback controls pane currently associated with the view.

After macOS 11, the floating style controls will always be used when presenting in fullscreen and AVPlayerViewControlsStyleNone is not specified.

pub unsafe fn setControlsStyle(&self, controls_style: AVPlayerViewControlsStyle)

Setter for controlsStyle.

pub unsafe fn videoGravity(&self) -> Retained<AVLayerVideoGravity>

Available on crate feature objc2-av-foundation only.

A string defining how the video is displayed within an AVPlayerLayer bounds rect.

Options are AVLayerVideoGravityResizeAspect, AVLayerVideoGravityResizeAspectFill and AVLayerVideoGravityResize. AVLayerVideoGravityResizeAspect is default.

pub unsafe fn setVideoGravity(&self, video_gravity: &AVLayerVideoGravity)

Available on crate feature objc2-av-foundation only.

Setter for videoGravity.

pub unsafe fn isReadyForDisplay(&self) -> bool

Boolean indicating that the first video frame has been made ready for display for the current item of the associated AVPlayer.

pub unsafe fn videoBounds(&self) -> NSRect

The current size and position of the video image as displayed within the receiver’s view’s bounds.

pub unsafe fn contentOverlayView(&self) -> Option<Retained<NSView>>

Use the content overlay view to add additional custom views between the video content and the controls.

pub unsafe fn updatesNowPlayingInfoCenter(&self) -> bool

Whether or not the now playing info center should be updated. Default is YES.

pub unsafe fn setUpdatesNowPlayingInfoCenter( &self, updates_now_playing_info_center: bool, )

pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn AVPlayerViewDelegate>>>

The receiver’s delegate.

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn AVPlayerViewDelegate>>, )

This is a weak property. Setter for delegate.

pub unsafe fn speeds(&self) -> Retained<NSArray<AVPlaybackSpeed>>

Available on crate feature AVPlaybackSpeed only.

A list of user selectable playback speeds to be shown in the playback speed control.

By default this property will be set to the systemDefaultSpeeds class property. Setting this property to nil will hide the playback speed selection UI.

To set the currently selected playback speed programmatically, either set the defaultRate on the AVPlayer associated with this view controller or use the selectSpeed method on AVPlayerView.

pub unsafe fn setSpeeds(&self, speeds: &NSArray<AVPlaybackSpeed>)

Available on crate feature AVPlaybackSpeed only.

Setter for speeds.

pub unsafe fn selectedSpeed(&self) -> Option<Retained<AVPlaybackSpeed>>

Available on crate feature AVPlaybackSpeed only.

The currently selected playback speed.

Changes to the associated AVPlayer’s defaultRate will be reflected in this property and vice versa. If the associated AVPlayer’s defaultRate is set to a value that does not match a speed in the speeds list property, the selected speed will be nil.

pub unsafe fn selectSpeed(&self, speed: &AVPlaybackSpeed)

Available on crate feature AVPlaybackSpeed only.

Parameter speed: The playback speed to select.

Sets the input AVPlaybackSpeed as the selected speed.

Calls to selectSpeed with AVPlaybackSpeeds not contained within the speeds property array will be ignored.

pub unsafe fn allowsVideoFrameAnalysis(&self) -> bool

When set to YES, the AVPlayerView will try to find objects, text and people while the media is paused. When an object is found, the user will be able to interact with it selecting and right clicking to present a context menu. Default is YES.

pub unsafe fn setAllowsVideoFrameAnalysis( &self, allows_video_frame_analysis: bool, )

pub unsafe fn videoFrameAnalysisTypes(&self) -> AVVideoFrameAnalysisType

Available on crate feature AVKitTypes only.

The types of items AVPlayerView looks for in a paused video frame.

pub unsafe fn setVideoFrameAnalysisTypes( &self, video_frame_analysis_types: AVVideoFrameAnalysisType, )

Available on crate feature AVKitTypes only.
pub unsafe fn allowsMagnification(&self) -> bool

Whether the magnify gesture will change the video’s view magnification.

The default value is NO. This property only effects whether the magnify gesture triggers magnification. A client can still programmatically change magnification even when the value of this is NO. This behavior matches the behavior of NSScrollView.

pub unsafe fn setAllowsMagnification(&self, allows_magnification: bool)

Setter for allowsMagnification.

pub unsafe fn magnification(&self) -> CGFloat

Available on crate feature objc2-core-foundation only.

The factor by which the video’s view is currently scaled.

The default value is 1.0. The value cannot be smaller than 1.0 or larger 64.0. Nearest neighbor interpolation will be used once the content has been zoomed past a certain factor.

pub unsafe fn setMagnification(&self, magnification: CGFloat)

Available on crate feature objc2-core-foundation only.

Setter for magnification.

pub unsafe fn setMagnification_centeredAtPoint( &self, magnification: CGFloat, point: CGPoint, )

Available on crate feature objc2-core-foundation only.

Scales the video’s view by a specified factor and centers the result on a specified point.

Parameter magnification: The factor by which to scale the video’s view.

Parameter point: The point (in view space) on which to center magnification.

The magnification cannot be smaller than 1.0 or larger 64.0. Nearest neighbor interpolation will be used once the content has been zoomed past a certain factor.

Source

impl AVPlayerView

Methods declared on superclass NSView.

pub unsafe fn initWithFrame( this: Allocated<Self>, frame_rect: NSRect, ) -> Retained<Self>

pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder, ) -> Option<Retained<Self>>

Source

impl AVPlayerView

Methods declared on superclass NSResponder.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Source

impl AVPlayerView

Methods declared on superclass NSObject.

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Source

impl AVPlayerView

AVPlayerViewCustomization.

pub unsafe fn showsFrameSteppingButtons(&self) -> bool

Replace scanning controls in the playback UI with frame stepping buttons. Default is NO.

pub unsafe fn setShowsFrameSteppingButtons( &self, shows_frame_stepping_buttons: bool, )

pub unsafe fn showsSharingServiceButton(&self) -> bool

Whether or not the controls pane will show a sharing service button when the current player item can be shared. Default is NO.

pub unsafe fn setShowsSharingServiceButton( &self, shows_sharing_service_button: bool, )

pub unsafe fn actionPopUpButtonMenu(&self) -> Option<Retained<NSMenu>>

Clients can set this property in order to show an action pop up button. Default is nil.

pub unsafe fn setActionPopUpButtonMenu( &self, action_pop_up_button_menu: Option<&NSMenu>, )

pub unsafe fn showsFullScreenToggleButton(&self) -> bool

Whether or not the controls pane will show a full screen toggle button. Default is NO.

pub unsafe fn setShowsFullScreenToggleButton( &self, shows_full_screen_toggle_button: bool, )

pub unsafe fn showsTimecodes(&self) -> bool

If timecodes are available, allow the AVPlayerView controls to enter timecode mode. Default is NO.

pub unsafe fn setShowsTimecodes(&self, shows_timecodes: bool)

Setter for showsTimecodes.

Source

impl AVPlayerView

AVPlayerViewTrimming.

pub unsafe fn canBeginTrimming(&self) -> bool

Whether or not the current media can be trimmed.

pub unsafe fn beginTrimmingWithCompletionHandler( &self, handler: Option<&Block<dyn Fn(AVPlayerViewTrimResult)>>, )

Available on crate feature block2 only.

Parameter handler: A completion handler that is executed when the user selects either the Trim or Cancel button in the trimming UI.

Sets the controls panel into trimming mode and blocks until the user selects either the Trim or the Cancel button.

Source

impl AVPlayerView

AVPlayerViewChapterIndicator.

pub unsafe fn flashChapterNumber_chapterTitle( &self, chapter_number: NSUInteger, chapter_title: Option<&NSString>, )

Parameter chapterNumber: The chapter number (required).

Parameter chapterTitle: The chapter title (optional).

Display the provided chapter number and title momentarily.

Source

impl AVPlayerView

AVPlayerViewPictureInPictureSupport.

pub unsafe fn allowsPictureInPicturePlayback(&self) -> bool

Whether or not the receiver allows Picture in Picture playback. Default is NO.

pub unsafe fn setAllowsPictureInPicturePlayback( &self, allows_picture_in_picture_playback: bool, )

pub unsafe fn pictureInPictureDelegate( &self, ) -> Option<Retained<ProtocolObject<dyn AVPlayerViewPictureInPictureDelegate>>>

A delegate for customizing Picture in Picture playback experience.

pub unsafe fn setPictureInPictureDelegate( &self, picture_in_picture_delegate: Option<&ProtocolObject<dyn AVPlayerViewPictureInPictureDelegate>>, )

This is a weak property. Setter for pictureInPictureDelegate.

Methods from Deref<Target = NSView>

pub unsafe fn superview(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn subviews(&self) -> Retained<NSArray<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn setSubviews(&self, subviews: &NSArray<NSView>)

Available on crate feature NSResponder only.

Setter for subviews.

pub unsafe fn isDescendantOf(&self, view: &NSView) -> bool

Available on crate feature NSResponder only.
pub unsafe fn ancestorSharedWithView( &self, view: &NSView, ) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn opaqueAncestor(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn isHidden(&self) -> bool

Available on crate feature NSResponder only.
pub fn setHidden(&self, hidden: bool)

Available on crate feature NSResponder only.

Setter for isHidden.

pub unsafe fn isHiddenOrHasHiddenAncestor(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn getRectsBeingDrawn_count( &self, rects: *mut *const CGRect, count: *mut isize, )

Available on crate feature NSResponder only.
pub unsafe fn needsToDrawRect(&self, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub unsafe fn wantsDefaultClipping(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn viewDidHide(&self)

Available on crate feature NSResponder only.
pub unsafe fn viewDidUnhide(&self)

Available on crate feature NSResponder only.
pub unsafe fn addSubview(&self, view: &NSView)

Available on crate feature NSResponder only.
pub unsafe fn sortSubviewsUsingFunction_context( &self, compare: unsafe extern "C-unwind" fn(_: NonNull<NSView>, _: NonNull<NSView>, _: *mut c_void) -> NSComparisonResult, context: *mut c_void, )

Available on crate feature NSResponder only.
pub unsafe fn viewDidMoveToWindow(&self)

Available on crate feature NSResponder only.
pub unsafe fn viewWillMoveToSuperview(&self, new_superview: Option<&NSView>)

Available on crate feature NSResponder only.
pub unsafe fn viewDidMoveToSuperview(&self)

Available on crate feature NSResponder only.
pub unsafe fn didAddSubview(&self, subview: &NSView)

Available on crate feature NSResponder only.
pub unsafe fn willRemoveSubview(&self, subview: &NSView)

Available on crate feature NSResponder only.
pub unsafe fn removeFromSuperview(&self)

Available on crate feature NSResponder only.
pub unsafe fn replaceSubview_with(&self, old_view: &NSView, new_view: &NSView)

Available on crate feature NSResponder only.
pub unsafe fn removeFromSuperviewWithoutNeedingDisplay(&self)

Available on crate feature NSResponder only.
pub unsafe fn viewDidChangeBackingProperties(&self)

Available on crate feature NSResponder only.
pub unsafe fn postsFrameChangedNotifications(&self) -> bool

Available on crate feature NSResponder only.
pub fn setPostsFrameChangedNotifications( &self, posts_frame_changed_notifications: bool, )

Available on crate feature NSResponder only.
pub unsafe fn resizeSubviewsWithOldSize(&self, old_size: CGSize)

Available on crate feature NSResponder only.
pub unsafe fn resizeWithOldSuperviewSize(&self, old_size: CGSize)

Available on crate feature NSResponder only.
pub unsafe fn autoresizesSubviews(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)

Available on crate feature NSResponder only.

Setter for autoresizesSubviews.

pub unsafe fn autoresizingMask(&self) -> NSAutoresizingMaskOptions

Available on crate feature NSResponder only.
pub unsafe fn setAutoresizingMask( &self, autoresizing_mask: NSAutoresizingMaskOptions, )

Available on crate feature NSResponder only.

Setter for autoresizingMask.

pub unsafe fn setFrameOrigin(&self, new_origin: CGPoint)

Available on crate feature NSResponder only.
pub unsafe fn setFrameSize(&self, new_size: CGSize)

Available on crate feature NSResponder only.
pub fn frame(&self) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn setFrame(&self, frame: CGRect)

Available on crate feature NSResponder only.

Setter for frame.

pub unsafe fn setBoundsOrigin(&self, new_origin: CGPoint)

Available on crate feature NSResponder only.
pub unsafe fn setBoundsSize(&self, new_size: CGSize)

Available on crate feature NSResponder only.
pub unsafe fn translateOriginToPoint(&self, translation: CGPoint)

Available on crate feature NSResponder only.
pub unsafe fn scaleUnitSquareToSize(&self, new_unit_size: CGSize)

Available on crate feature NSResponder only.
pub fn bounds(&self) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn setBounds(&self, bounds: CGRect)

Available on crate feature NSResponder only.

Setter for bounds.

pub fn isFlipped(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn isRotatedFromBase(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn isRotatedOrScaledFromBase(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn isOpaque(&self) -> bool

Available on crate feature NSResponder only.
pub fn convertPoint_fromView( &self, point: CGPoint, view: Option<&NSView>, ) -> CGPoint

Available on crate feature NSResponder only.
pub unsafe fn convertPoint_toView( &self, point: CGPoint, view: Option<&NSView>, ) -> CGPoint

Available on crate feature NSResponder only.
pub unsafe fn convertSize_fromView( &self, size: CGSize, view: Option<&NSView>, ) -> CGSize

Available on crate feature NSResponder only.
pub unsafe fn convertSize_toView( &self, size: CGSize, view: Option<&NSView>, ) -> CGSize

Available on crate feature NSResponder only.
pub unsafe fn convertRect_fromView( &self, rect: CGRect, view: Option<&NSView>, ) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRect_toView(&self, rect: CGRect, view: Option<&NSView>) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn backingAlignedRect_options( &self, rect: CGRect, options: NSAlignmentOptions, ) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn centerScanRect(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn convertPointToBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub unsafe fn convertPointFromBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub unsafe fn convertSizeToBacking(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub unsafe fn convertSizeFromBacking(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub unsafe fn convertRectToBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn convertRectFromBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn convertPointToLayer(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub unsafe fn convertPointFromLayer(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub unsafe fn convertSizeToLayer(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub unsafe fn convertSizeFromLayer(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub unsafe fn convertRectToLayer(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn convertRectFromLayer(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn canDrawConcurrently(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setCanDrawConcurrently(&self, can_draw_concurrently: bool)

Available on crate feature NSResponder only.

Setter for canDrawConcurrently.

pub unsafe fn canDraw(&self) -> bool

👎Deprecated: If a view needs display, -drawRect: or -updateLayer will be called automatically when the view is able to draw. To check whether a view is in a window, call -window. To check whether a view is hidden, call -isHiddenOrHasHiddenAncestor.
Available on crate feature NSResponder only.
pub unsafe fn setNeedsDisplayInRect(&self, invalid_rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn needsDisplay(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setNeedsDisplay(&self, needs_display: bool)

Available on crate feature NSResponder only.

Setter for needsDisplay.

pub unsafe fn lockFocus(&self)

👎Deprecated: To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.
Available on crate feature NSResponder only.
pub unsafe fn unlockFocus(&self)

👎Deprecated: To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.
Available on crate feature NSResponder only.
pub unsafe fn lockFocusIfCanDraw(&self) -> bool

👎Deprecated: To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.
Available on crate feature NSResponder only.
pub fn visibleRect(&self) -> CGRect

Available on crate feature NSResponder only.

The portion of the view that isn’t clipped by its superviews.

Visibility, as reflected by this property, doesn’t account for whether other view or window objects overlap the current view or whether the current view is installed in a window at all. This value of this property is NSZeroRect if the current view is effectively hidden.

During a printing operation, the visible rectangle is further clipped to the page being imaged.

pub unsafe fn display(&self)

Available on crate feature NSResponder only.
pub unsafe fn displayIfNeeded(&self)

Available on crate feature NSResponder only.
pub unsafe fn displayIfNeededIgnoringOpacity(&self)

Available on crate feature NSResponder only.
pub unsafe fn displayRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn displayIfNeededInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn displayRectIgnoringOpacity(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn displayIfNeededInRectIgnoringOpacity(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn drawRect(&self, dirty_rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn viewWillDraw(&self)

Available on crate feature NSResponder only.
pub unsafe fn scrollPoint(&self, point: CGPoint)

Available on crate feature NSResponder only.
pub unsafe fn scrollRectToVisible(&self, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub unsafe fn adjustScroll(&self, new_visible: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn scrollRect_by(&self, rect: CGRect, delta: CGSize)

👎Deprecated: Use NSScrollView to achieve scrolling views.
Available on crate feature NSResponder only.
pub unsafe fn translateRectsNeedingDisplayInRect_by( &self, clip_rect: CGRect, delta: CGSize, )

Available on crate feature NSResponder only.
pub unsafe fn hitTest(&self, point: CGPoint) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn mouse_inRect(&self, point: CGPoint, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub unsafe fn viewWithTag(&self, tag: isize) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn tag(&self) -> isize

Available on crate feature NSResponder only.
pub unsafe fn needsPanelToBecomeKey(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn mouseDownCanMoveWindow(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn acceptsTouchEvents(&self) -> bool

👎Deprecated: Use allowedTouchTypes instead
Available on crate feature NSResponder only.
pub unsafe fn setAcceptsTouchEvents(&self, accepts_touch_events: bool)

👎Deprecated: Use allowedTouchTypes instead
Available on crate feature NSResponder only.

Setter for acceptsTouchEvents.

pub unsafe fn wantsRestingTouches(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setWantsRestingTouches(&self, wants_resting_touches: bool)

Available on crate feature NSResponder only.

Setter for wantsRestingTouches.

pub unsafe fn layerContentsRedrawPolicy( &self, ) -> NSViewLayerContentsRedrawPolicy

Available on crate feature NSResponder only.
pub unsafe fn setLayerContentsRedrawPolicy( &self, layer_contents_redraw_policy: NSViewLayerContentsRedrawPolicy, )

Available on crate feature NSResponder only.
pub unsafe fn layerContentsPlacement(&self) -> NSViewLayerContentsPlacement

Available on crate feature NSResponder only.
pub unsafe fn setLayerContentsPlacement( &self, layer_contents_placement: NSViewLayerContentsPlacement, )

Available on crate feature NSResponder only.
pub unsafe fn wantsLayer(&self) -> bool

Available on crate feature NSResponder only.
pub fn setWantsLayer(&self, wants_layer: bool)

Available on crate feature NSResponder only.

Setter for wantsLayer.

pub unsafe fn wantsUpdateLayer(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn updateLayer(&self)

Available on crate feature NSResponder only.
pub unsafe fn canDrawSubviewsIntoLayer(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setCanDrawSubviewsIntoLayer( &self, can_draw_subviews_into_layer: bool, )

Available on crate feature NSResponder only.
pub unsafe fn layoutSubtreeIfNeeded(&self)

Available on crate feature NSResponder only.
pub unsafe fn layout(&self)

Available on crate feature NSResponder only.
pub unsafe fn needsLayout(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setNeedsLayout(&self, needs_layout: bool)

Available on crate feature NSResponder only.

Setter for needsLayout.

pub unsafe fn layerUsesCoreImageFilters(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setLayerUsesCoreImageFilters( &self, layer_uses_core_image_filters: bool, )

Available on crate feature NSResponder only.
pub unsafe fn clipsToBounds(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setClipsToBounds(&self, clips_to_bounds: bool)

Available on crate feature NSResponder only.

Setter for clipsToBounds.

pub unsafe fn postsBoundsChangedNotifications(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setPostsBoundsChangedNotifications( &self, posts_bounds_changed_notifications: bool, )

Available on crate feature NSResponder only.
pub unsafe fn toolTip(&self) -> Option<Retained<NSString>>

Available on crate feature NSResponder only.
pub unsafe fn setToolTip(&self, tool_tip: Option<&NSString>)

Available on crate feature NSResponder only.

Setter for toolTip.

pub unsafe fn addToolTipRect_owner_userData( &self, rect: CGRect, owner: &AnyObject, data: *mut c_void, ) -> isize

Available on crate feature NSResponder only.
pub unsafe fn removeToolTip(&self, tag: isize)

Available on crate feature NSResponder only.
pub unsafe fn removeAllToolTips(&self)

Available on crate feature NSResponder only.
pub unsafe fn viewWillStartLiveResize(&self)

Available on crate feature NSResponder only.
pub unsafe fn viewDidEndLiveResize(&self)

Available on crate feature NSResponder only.
pub unsafe fn inLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn preservesContentDuringLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn rectPreservedDuringLiveResize(&self) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn rectForSmartMagnificationAtPoint_inRect( &self, location: CGPoint, visible_rect: CGRect, ) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn prepareForReuse(&self)

Available on crate feature NSResponder only.
pub unsafe fn prepareContentInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn preparedContentRect(&self) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn setPreparedContentRect(&self, prepared_content_rect: CGRect)

Available on crate feature NSResponder only.

Setter for preparedContentRect.

pub unsafe fn allowsVibrancy(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn viewDidChangeEffectiveAppearance(&self)

Available on crate feature NSResponder only.

Override point for reacting to the effective appearance of the receiver changing. At this point effectiveAppearance property reflects the new appearance.

pub unsafe fn nextKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn setNextKeyView(&self, next_key_view: Option<&NSView>)

Available on crate feature NSResponder only.

Setter for nextKeyView.

pub unsafe fn previousKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn nextValidKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn previousValidKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn canBecomeKeyView(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setKeyboardFocusRingNeedsDisplayInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub unsafe fn drawFocusRingMask(&self)

Available on crate feature NSResponder only.
pub unsafe fn focusRingMaskBounds(&self) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn noteFocusRingMaskChanged(&self)

Available on crate feature NSResponder only.
pub unsafe fn dataWithEPSInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub unsafe fn dataWithPDFInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub unsafe fn print(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
pub unsafe fn knowsPageRange(&self, range: *mut NSRange) -> bool

Available on crate feature NSResponder only.
pub unsafe fn rectForPage(&self, page: isize) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn locationOfPrintRect(&self, rect: CGRect) -> CGPoint

Available on crate feature NSResponder only.
pub unsafe fn drawPageBorderWithSize(&self, border_size: CGSize)

Available on crate feature NSResponder only.
pub unsafe fn pageHeader(&self) -> Retained<NSAttributedString>

Available on crate feature NSResponder only.
pub unsafe fn pageFooter(&self) -> Retained<NSAttributedString>

Available on crate feature NSResponder only.
pub unsafe fn drawSheetBorderWithSize(&self, border_size: CGSize)

👎Deprecated: This is never invoked and the NSView implementation does nothing
Available on crate feature NSResponder only.
  • This method is obsolete. It will never be invoked from within AppKit, and NSView’s implementation of it does nothing. **
pub unsafe fn printJobTitle(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub unsafe fn beginDocument(&self)

Available on crate feature NSResponder only.
pub unsafe fn endDocument(&self)

Available on crate feature NSResponder only.
pub unsafe fn beginPageInRect_atPlacement( &self, rect: CGRect, location: CGPoint, )

Available on crate feature NSResponder only.
pub unsafe fn endPage(&self)

Available on crate feature NSResponder only.
pub unsafe fn unregisterDraggedTypes(&self)

Available on crate feature NSResponder only.
pub unsafe fn exitFullScreenModeWithOptions( &self, options: Option<&NSDictionary<NSString>>, )

Available on crate feature NSResponder only.
pub unsafe fn isInFullScreenMode(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn showDefinitionForAttributedString_atPoint( &self, attr_string: Option<&NSAttributedString>, text_baseline_origin: CGPoint, )

Available on crate feature NSResponder only.
pub unsafe fn isDrawingFindIndicator(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn safeAreaInsets(&self) -> NSEdgeInsets

Available on crate feature NSResponder only.
pub unsafe fn additionalSafeAreaInsets(&self) -> NSEdgeInsets

Available on crate feature NSResponder only.
pub unsafe fn setAdditionalSafeAreaInsets( &self, additional_safe_area_insets: NSEdgeInsets, )

Available on crate feature NSResponder only.
pub unsafe fn safeAreaRect(&self) -> CGRect

Available on crate feature NSResponder only.
pub unsafe fn updateTrackingAreas(&self)

Available on crate feature NSResponder only.
pub unsafe fn discardCursorRects(&self)

Available on crate feature NSResponder only.
pub unsafe fn resetCursorRects(&self)

Available on crate feature NSResponder only.
pub unsafe fn addTrackingRect_owner_userData_assumeInside( &self, rect: CGRect, owner: &AnyObject, data: *mut c_void, flag: bool, ) -> isize

Available on crate feature NSResponder only.
pub fn removeTrackingRect(&self, tag: isize)

Available on crate feature NSResponder only.
pub unsafe fn convertPointToBase(&self, point: CGPoint) -> CGPoint

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn convertPointFromBase(&self, point: CGPoint) -> CGPoint

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn convertSizeToBase(&self, size: CGSize) -> CGSize

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn convertSizeFromBase(&self, size: CGSize) -> CGSize

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn convertRectToBase(&self, rect: CGRect) -> CGRect

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn convertRectFromBase(&self, rect: CGRect) -> CGRect

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn performMnemonic(&self, string: &NSString) -> bool

👎Deprecated: This has always returned NO and had no effect on macOS
Available on crate feature NSResponder only.
pub unsafe fn shouldDrawColor(&self) -> bool

👎Deprecated: This method no longer does anything
Available on crate feature NSResponder only.
pub unsafe fn gState(&self) -> isize

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn allocateGState(&self)

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn setUpGState(&self)

👎Deprecated
Available on crate feature NSResponder only.
pub unsafe fn renewGState(&self)

👎Deprecated
Available on crate feature NSResponder only.

Methods from Deref<Target = NSResponder>

pub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>

pub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)

Setter for nextResponder.

pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool

pub unsafe fn noResponderFor(&self, event_selector: Sel)

pub unsafe fn acceptsFirstResponder(&self) -> bool

pub unsafe fn becomeFirstResponder(&self) -> bool

pub unsafe fn resignFirstResponder(&self) -> bool

pub unsafe fn flushBufferedKeyEvents(&self)

pub unsafe fn menu(&self) -> Option<Retained<NSMenu>>

Available on crate feature NSMenu only.
pub unsafe fn setMenu(&self, menu: Option<&NSMenu>)

Available on crate feature NSMenu only.

Setter for menu.

pub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)

pub unsafe fn supplementalTargetForAction_sender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>

pub unsafe fn undoManager(&self) -> Option<Retained<NSUndoManager>>

pub unsafe fn presentError(&self, error: &NSError) -> bool

pub unsafe fn willPresentError(&self, error: &NSError) -> Retained<NSError>

pub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)

pub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)

pub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)

pub unsafe fn performMnemonic(&self, string: &NSString) -> bool

👎Deprecated: This has always returned NO and had no effect on macOS

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}